"use client";

/**
 * 天气信息组件
 * 包含当前天气和天气预报展示
 * 支持加载状态处理和API数据格式转换
 */

import { FC } from "react";
import { WeatherData } from "../types/magic-mirror";
import WbSunnyIcon from "@mui/icons-material/WbSunny";
import CircularProgress from "@mui/material/CircularProgress";

interface WeatherSectionProps {
  data?: WeatherData; // 允许undefined状态（加载中）
}

const WeatherSection: FC<WeatherSectionProps> = ({ data }) => {
  // 处理加载状态
  if (!data) {
    return (
      <div className="absolute top-8 right-0 w-64 flex items-center justify-center h-32">
        <CircularProgress size={24} color="inherit" />
        <span className="ml-2 text-gray-400">天气加载中...</span>
      </div>
    );
  }

  // 日出日落时间格式化（去除日期部分）
  const formatTime = (isoTime: string) => {
    try {
      return new Date(isoTime).toLocaleTimeString("zh-CN", {
        hour: "2-digit",
        minute: "2-digit",
        hour12: false,
      });
    } catch {
      return isoTime.split("T")[1]?.slice(0, 5) || isoTime; // 回退处理
    }
  };

  // 获取天气图标
  const getWeatherIcon = (condition: string) => {
    const iconMap: Record<string, string> = {
      晴: "☀️",
      多云: "⛅",
      阴: "☁️",
      小雨: "🌧️",
      中雨: "🌧️",
      大雨: "⛈️",
      暴雨: "🌧️💦",
      // 其他天气类型可继续扩展...
    };
    return iconMap[condition] || "🌤️";
  };

  return (
    <>
      {/* 当前天气模块 */}
      <div className="absolute top-8 right-0 w-64 space-y-4">
        {/* 风速和日出日落信息 */}
        <div className="grid grid-cols-2 gap-4 text-sm">
          <div className="space-y-1">
            <div className="text-gray-400">风速</div>
            <div className="text-gray-300">
              {data.windSpeed}km/h {data.windDirection}
            </div>
          </div>
          <div className="space-y-1">
            <div className="text-gray-400">日出/日落</div>
            <div className="text-gray-300">
              {formatTime(data.sunrise)} / {formatTime(data.sunset)}
            </div>
          </div>
        </div>

        {/* 温度显示区域 */}
        <div className="flex items-center gap-4">
          <div className="text-4xl">{getWeatherIcon(data.condition)}</div>
          <div>
            <div className="text-3xl">{data.temp}°C</div>
            <div className="text-gray-400 text-sm">体感 {data.feelsLike}°C</div>
          </div>
        </div>

        {/* 紫外线指数 */}
        <div className="space-y-2">
          <div className="text-gray-400 text-sm">紫外线指数</div>
          <div className="text-gray-300">{data.uvIndex}</div>
        </div>
      </div>

      {/* 天气预报模块 */}
      <div className="absolute top-64 right-8 w-64 space-y-2">
        {data.forecast.slice(0, 5).map((day, index) => (
          <div
            key={day.day}
            className="flex justify-between items-center text-sm group"
            style={{ opacity: 1 - index * 0.15 }}
          >
            <div className="text-gray-300 w-12">{day.day}</div>
            <div className="text-gray-400 transition-opacity opacity-70 group-hover:opacity-100">
              {getWeatherIcon(day.condition)}
            </div>
            <div className="flex gap-2">
              <span className="text-blue-300">{day.low}°</span>
              <span className="text-red-300">{day.high}°</span>
            </div>
          </div>
        ))}
      </div>
    </>
  );
};

export default WeatherSection;
